@@ -106,9 +106,9 @@ class DAG(nx.DiGraph):
         >>> G.add_node(node='B', weight=0.3)
 
         The weight of these nodes can be accessed as:
-        >>> G.node['B']
+        >>> G.nodes['B']
         {'weight': 0.3}
-        >>> G.node['A']
+        >>> G.nodes['A']
         {'weight': None}
         """
 
@@ -143,16 +143,16 @@ class DAG(nx.DiGraph):
         >>> from pgmpy.base import DAG
         >>> G = DAG()
         >>> G.add_nodes_from(nodes=['A', 'B', 'C'])
-        >>> sorted(G.nodes())
-        ['A', 'B', 'C']
+        >>> G.nodes()
+        NodeView(('A', 'B', 'C'))
 
         Adding nodes with weights:
         >>> G.add_nodes_from(nodes=['D', 'E'], weights=[0.3, 0.6])
-        >>> G.node['D']
+        >>> G.nodes['D']
         {'weight': 0.3}
-        >>> G.node['E']
+        >>> G.nodes['E']
         {'weight': 0.6}
-        >>> G.node['A']
+        >>> G.nodes['A']
         {'weight': None}
         """
         nodes = list(nodes)
@@ -190,16 +190,16 @@ class DAG(nx.DiGraph):
         >>> G.add_nodes_from(nodes=['Alice', 'Bob', 'Charles'])
         >>> G.add_edge(u='Alice', v='Bob')
         >>> G.nodes()
-        ['Alice', 'Bob', 'Charles']
+        NodeView(('Alice', 'Bob', 'Charles'))
         >>> G.edges()
-        [('Alice', 'Bob')]
+        OutEdgeView([('Alice', 'Bob')])
 
         When the node is not already present in the graph:
         >>> G.add_edge(u='Alice', v='Ankur')
         >>> G.nodes()
-        ['Alice', 'Ankur', 'Bob', 'Charles']
+        NodeView(('Alice', 'Ankur', 'Bob', 'Charles'))
         >>> G.edges()
-        [('Alice', 'Bob'), ('Alice', 'Ankur')]
+        OutEdgeView([('Alice', 'Bob'), ('Alice', 'Ankur')])
 
         Adding edges with weight:
         >>> G.add_edge('Ankur', 'Maria', weight=0.1)
@@ -235,16 +235,16 @@ class DAG(nx.DiGraph):
         >>> G.add_nodes_from(nodes=['Alice', 'Bob', 'Charles'])
         >>> G.add_edges_from(ebunch=[('Alice', 'Bob'), ('Bob', 'Charles')])
         >>> G.nodes()
-        ['Alice', 'Bob', 'Charles']
+        NodeView(('Alice', 'Bob', 'Charles'))
         >>> G.edges()
-        [('Alice', 'Bob'), ('Bob', 'Charles')]
+        OutEdgeView([('Alice', 'Bob'), ('Bob', 'Charles')])
 
         When the node is not already in the model:
         >>> G.add_edges_from(ebunch=[('Alice', 'Ankur')])
         >>> G.nodes()
-        ['Alice', 'Bob', 'Charles', 'Ankur']
+        NodeView(('Alice', 'Bob', 'Charles', 'Ankur'))
         >>> G.edges()
-        [('Alice', 'Bob'), ('Bob', 'Charles'), ('Alice', 'Ankur')]
+        OutEdgeView([('Alice', 'Bob'), ('Bob', 'Charles'), ('Alice', 'Ankur')])
 
         Adding edges with weights:
         >>> G.add_edges_from([('Ankur', 'Maria'), ('Maria', 'Mason')],
@@ -301,7 +301,7 @@ class DAG(nx.DiGraph):
         >>> G = DAG(ebunch=[('diff', 'grade'), ('intel', 'grade')])
         >>> moral_graph = G.moralize()
         >>> moral_graph.edges()
-        [('intel', 'grade'), ('intel', 'diff'), ('grade', 'diff')]
+        EdgeView([('intel', 'grade'), ('intel', 'diff'), ('grade', 'diff')])
         """
         moral_graph = UndirectedGraph()
         moral_graph.add_nodes_from(self.nodes())
@@ -389,8 +389,8 @@ class DAG(nx.DiGraph):
         >>> from pgmpy.base import DAG
         >>> chain = DAG([('X', 'Y'), ('Y', 'Z')])
         >>> chain.get_independencies()
-        (X _|_ Z | Y)
-        (Z _|_ X | Y)
+        (X \u27C2 Z | Y)
+        (Z \u27C2 X | Y)
         """
         independencies = Independencies()
         for start in self.nodes():
@@ -425,13 +425,13 @@ class DAG(nx.DiGraph):
 
         Examples
         --------
-        >>> from pgmpy.models import DAG
+        >>> from pgmpy.base import DAG
         >>> student = DAG()
         >>> student.add_edges_from([('diff', 'grade'), ('intel', 'grade'),
         >>>                         ('grade', 'letter'), ('intel', 'SAT')])
         >>> ind = student.local_independencies('grade')
         >>> ind
-        (grade _|_ SAT | diff, intel)
+        (grade \u27C2 SAT | diff, intel)
         """
 
         independencies = Independencies()
@@ -509,7 +509,7 @@ class DAG(nx.DiGraph):
         >>> student.add_edges_from([('diff', 'grade'), ('intel', 'grade'),
         ...                         ('intel', 'SAT'), ('grade', 'letter')])
         >>> student.get_immoralities()
-        {('diff','intel')}
+        {('diff', 'intel')}
         """
         immoralities = set()
         for node in self.nodes():
@@ -602,6 +602,7 @@ class DAG(nx.DiGraph):
         {'diff': {'diff', 'grades'}}
         >>> student.active_trail_nodes(['diff', 'intel'], observed='grades')
         {'diff': {'diff', 'intel'}, 'intel': {'diff', 'intel'}}
+
         References
         ----------
         Details of the algorithm can be found in 'Probabilistic Graphical Model
@@ -718,13 +719,13 @@ class DAG(nx.DiGraph):
         Initialize a DAG
         >>> graph = DAG()
         >>> graph.add_edges_from([('X', 'A'),
-                                  ('A', 'Y'),
-                                  ('A', 'B')])
-        Applying the do-operator will return a new DAG with the desired structure.
-        >>> graph_do_A = self.graph.do('A')
-        Which we can verify is missing the edges we would expect.
+        ...                       ('A', 'Y'),
+        ...                       ('A', 'B')])
+        >>> # Applying the do-operator will return a new DAG with the desired structure.
+        >>> graph_do_A = graph.do('A')
+        >>> # Which we can verify is missing the edges we would expect.
         >>> graph_do_A.edges
-        [('A', 'B'), ('A', 'Y')]
+        OutEdgeView([('A', 'B'), ('A', 'Y')])
 
         References
         ----------
@@ -740,7 +741,7 @@ class DAG(nx.DiGraph):
     def get_ancestral_graph(self, nodes):
         """
         Returns the ancestral graph of the given `nodes`. The ancestral graph only
-        contains the nodes which are ancestors of atleast one of the variables in 
+        contains the nodes which are ancestors of atleast one of the variables in
         node.
 
         Parameters
@@ -758,10 +759,132 @@ class DAG(nx.DiGraph):
         >>> dag = DAG([('A', 'C'), ('B', 'C'), ('D', 'A'), ('D', 'B')])
         >>> anc_dag = dag.get_ancestral_graph(nodes=['A', 'B'])
         >>> anc_dag.edges()
-        [('D', 'A'), ('D', 'B')]
+        OutEdgeView([('D', 'A'), ('D', 'B')])
         """
         return self.subgraph(nodes=self._get_ancestors_of(nodes=nodes))
 
+    def to_daft(
+        self, node_pos=None, latex=True, pgm_params={}, edge_params={}, node_params={}
+    ):
+        """
+        Returns a daft (https://docs.daft-pgm.org/en/latest/) object which can be rendered for
+        publication quality plots. The returned object's render method can be called to see the plots.
+
+        Parameters
+        ----------
+        node_pos: str or dict (optional)
+            If str: Must be one of the following: circular, kamada_kawai, planar, random, shell, sprint,
+                spectral, spiral. Please refer: https://networkx.org/documentation/stable//reference/drawing.html#module-networkx.drawing.layout for details on these layouts.
+
+            If dict should be of the form {node: (x coordinate, y coordinate)} describing the x and y coordinate of each
+            node.
+
+            If no argument is provided uses random layout.
+
+        latex: boolean
+            Whether to use latex for rendering the node names.
+
+        pgm_params: dict (optional)
+            Any additional parameters that need to be passed to `daft.PGM` initializer.
+            Should be of the form: {param_name: param_value}
+
+        edge_params: dict (optional)
+            Any additional edge parameters that need to be passed to `daft.add_edge` method.
+            Should be of the form: {(u1, v1): {param_name: param_value}, (u2, v2): {...} }
+
+        node_params: dict (optional)
+            Any additional node parameters that need to be passed to `daft.add_node` method.
+            Should be of the form: {node1: {param_name: param_value}, node2: {...} }
+
+        Returns
+        -------
+        daft.PGM object: A plot of the DAG.
+
+        Examples
+        --------
+        >>> from pgmpy.base import DAG
+        >>> dag = DAG([('a', 'b'), ('b', 'c'), ('d', 'c')])
+        >>> dag.to_daft(node_pos={'a': (0, 0), 'b': (1, 0), 'c': (2, 0), 'd': (1, 1)})
+        <daft.PGM at 0x7fc756e936d0>
+        >>> dag.to_daft(node_pos="circular")
+        <daft.PGM at 0x7f9bb48c5eb0>
+        >>> dag.to_daft(node_pos="circular", pgm_params={'observed_style': 'inner'})
+        <daft.PGM at 0x7f9bb48b0bb0>
+        >>> dag.to_daft(node_pos="circular",
+        ...             edge_params={('a', 'b'): {'label': 2}},
+        ...             node_params={'a': {'shape': 'rectangle'}})
+        <daft.PGM at 0x7f9bb48b0bb0>
+        """
+        try:
+            from daft import PGM
+        except ImportError as e:
+            raise ImportError(
+                "Package daft required. Please visit: https://docs.daft-pgm.org/en/latest/ for installation instructions."
+            )
+
+        if node_pos is None:
+            node_pos = nx.random_layout(self)
+        elif isinstance(node_pos, str):
+            supported_layouts = {
+                "circular": nx.circular_layout,
+                "kamada_kawai": nx.kamada_kawai_layout,
+                "planar": nx.planar_layout,
+                "random": nx.random_layout,
+                "shell": nx.shell_layout,
+                "spring": nx.spring_layout,
+                "spectral": nx.spectral_layout,
+                "spiral": nx.spiral_layout,
+            }
+            if node_pos not in supported_layouts.keys():
+                raise ValueError(
+                    "Unknown node_pos argument. Please refer docstring for accepted values"
+                )
+            else:
+                node_pos = supported_layouts[node_pos](self)
+        elif isinstance(node_pos, dict):
+            for node in self.nodes():
+                if node not in node_pos.keys():
+                    raise ValueError(f"No position specified for {node}.")
+        else:
+            raise ValueError(
+                "Argument node_pos not valid. Please refer to the docstring."
+            )
+
+        daft_pgm = PGM(**pgm_params)
+        for node in self.nodes():
+            try:
+                extra_params = node_params[node]
+            except KeyError:
+                extra_params = dict()
+
+            if latex:
+                daft_pgm.add_node(
+                    node,
+                    fr"${node}$",
+                    node_pos[node][0],
+                    node_pos[node][1],
+                    observed=True,
+                    **extra_params,
+                )
+            else:
+                daft_pgm.add_node(
+                    node,
+                    f"{node}",
+                    node_pos[node][0],
+                    node_pos[node][1],
+                    observed=True,
+                    **extra_params,
+                )
+
+        for u, v in self.edges():
+            try:
+                extra_params = edge_params[(u, v)]
+            except KeyError:
+                extra_params = dict()
+            daft_pgm.add_edge(u, v, **extra_params)
+
+        return daft_pgm
+
 
 class PDAG(nx.DiGraph):
     """
