@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 from itertools import chain
+from warnings import warn
 
 import numpy as np
 import numbers
@@ -107,7 +108,7 @@ class BayesianEstimator(ParameterEstimator):
                 'pseudo_counts' = dirichlet hyperparameters; a single number or 2-D array
                  of shape (node_card, product of parents_card) with a "virtual" count for
                  each variable state in the CPD. The virtual counts are added to the
-                 actual state counts found in the data. (if a list is provided, a 
+                 actual state counts found in the data. (if a list is provided, a
                  lexicographic ordering of states is assumed)
             - If 'prior_type' is 'BDeu', then an 'equivalent_sample_size'
                  must be specified instead of 'pseudo_counts'. This is equivalent to
@@ -128,7 +129,9 @@ class BayesianEstimator(ParameterEstimator):
         >>> data = pd.DataFrame(data={'A': [0, 0, 1], 'B': [0, 1, 0], 'C': [1, 1, 0]})
         >>> model = BayesianModel([('A', 'C'), ('B', 'C')])
         >>> estimator = BayesianEstimator(model, data)
-        >>> cpd_C = estimator.estimate_cpd('C', prior_type="dirichlet", pseudo_counts=[1, 2])
+        >>> cpd_C = estimator.estimate_cpd('C', prior_type="dirichlet",
+        ...                                pseudo_counts=[[1, 1, 1, 1],
+        ...                                               [2, 2, 2, 2]])
         >>> print(cpd_C)
         ╒══════╤══════╤══════╤══════╤════════════════════╕
         │ A    │ A(0) │ A(0) │ A(1) │ A(1)               │
@@ -147,6 +150,13 @@ class BayesianEstimator(ParameterEstimator):
         cpd_shape = (node_cardinality, np.prod(parents_cardinalities, dtype=int))
 
         prior_type = prior_type.lower()
+
+        # Throw a warning if pseudo_count is specified without prior_type=dirichlet
+        if (pseudo_counts and pseudo_counts != []) and (prior_type != "dirichlet"):
+            warn(
+                f"pseudo count specified with {prior_type} prior. It will be ignored, use dirichlet prior for specifying pseudo_counts"
+            )
+
         if prior_type == "k2":
             pseudo_counts = np.ones(cpd_shape, dtype=int)
         elif prior_type == "bdeu":
