@@ -203,15 +203,15 @@ class HillClimbSearch(StructureEstimator):
         ... data = pd.DataFrame(np.random.randint(0, 5, size=(5000, 9)), columns=list('ABCDEFGHI'))
         >>> # add 10th dependent variable
         ... data['J'] = data['A'] * data['B']
-        >>> est = HillClimbSearch(data, scoring_method=BicScore(data))
-        >>> best_model = est.estimate()
+        >>> est = HillClimbSearch(data)
+        >>> best_model = est.estimate(scoring_method=BicScore(data))
         >>> sorted(best_model.nodes())
         ['A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J']
         >>> best_model.edges()
-        [('B', 'J'), ('A', 'J')]
+        OutEdgeView([('B', 'J'), ('A', 'J')])
         >>> # search a model with restriction on the number of parents:
         >>> est.estimate(max_indegree=1).edges()
-        [('J', 'A'), ('B', 'J')]
+        OutEdgeView([('J', 'A'), ('B', 'J')])
         """
 
         # Step 1: Initial checks and setup for arguments
@@ -221,9 +221,12 @@ class HillClimbSearch(StructureEstimator):
             "bdeuscore": BDeuScore,
             "bicscore": BicScore,
         }
-        if (scoring_method.lower() not in supported_methods) and (
-            not isinstance(scoring_method, StructureScore)
-        ):
+        if (
+            (
+                isinstance(scoring_method, str)
+                and (scoring_method.lower() not in supported_methods)
+            )
+        ) and (not isinstance(scoring_method, StructureScore)):
             raise ValueError(
                 "scoring_method should either be one of k2score, bdeuscore, bicscore, or an instance of StructureScore"
             )
@@ -231,7 +234,7 @@ class HillClimbSearch(StructureEstimator):
         if isinstance(scoring_method, str):
             score = supported_methods[scoring_method.lower()](data=self.data)
         else:
-            score = scoring_method(data=self.data)
+            score = scoring_method
 
         if self.use_cache:
             score_fn = ScoreCache.ScoreCache(score, self.data).local_score
@@ -281,7 +284,8 @@ class HillClimbSearch(StructureEstimator):
             iteration = range(int(max_iter))
 
         # Step 2: For each iteration, find the best scoring operation and
-        #         do that to the current model.
+        #         do that to the current model. If no legal operation is
+        #         possible, sets best_operation=None.
         for _ in iteration:
             best_operation, best_score_delta = max(
                 self._legal_operations(
@@ -294,6 +298,7 @@ class HillClimbSearch(StructureEstimator):
                     fixed_edges,
                 ),
                 key=lambda t: t[1],
+                default=(None, None),
             )
 
             if best_operation is None or best_score_delta < epsilon:
