@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 from warnings import warn
-from itertools import combinations
+from itertools import combinations, permutations, chain
 
 import networkx as nx
 from tqdm import tqdm
@@ -237,15 +237,15 @@ class PC(StructureEstimator):
 
         Examples
         --------
-        >>> from pgmpy.estimators import PC 
-        >>> from pgmpy.models import DAG
+        >>> from pgmpy.estimators import PC
+        >>> from pgmpy.base import DAG
         >>> from pgmpy.independencies import Independencies
         >>> # build skeleton from list of independencies:
         ... ind = Independencies(['B', 'C'], ['A', ['B', 'C'], 'D'])
         >>> # we need to compute closure, otherwise this set of independencies doesn't
         ... # admit a faithful representation:
         ... ind = ind.closure()
-        >>> skel, sep_sets = PC.build_skeleton("ABCD", ind)
+        >>> skel, sep_sets = PC(independencies=ind).build_skeleton("ABCD", ind)
         >>> print(skel.edges())
         [('A', 'D'), ('B', 'D'), ('C', 'D')]
         >>> # build skeleton from d-seperations of DAG:
@@ -288,8 +288,9 @@ class PC(StructureEstimator):
             # size `lim_neighbors` which makes u and v independent.
             if variant == "orig":
                 for (u, v) in graph.edges():
-                    for separating_set in combinations(
-                        set(graph.neighbors(u)) - set([v]), lim_neighbors
+                    for separating_set in chain(
+                        combinations(set(graph.neighbors(u)) - set([v]), lim_neighbors),
+                        combinations(set(graph.neighbors(v)) - set([u]), lim_neighbors),
                     ):
                         # If a conditioning set exists remove the edge, store the separating set
                         # and move on to finding conditioning set for next edge.
@@ -310,8 +311,9 @@ class PC(StructureEstimator):
                 # In case of stable, precompute neighbors as this is the stable algorithm.
                 neighbors = {node: set(graph[node]) for node in graph.nodes()}
                 for (u, v) in graph.edges():
-                    for separating_set in combinations(
-                        neighbors[u] - set([v]), lim_neighbors
+                    for separating_set in chain(
+                        combinations(set(graph.neighbors(u)) - set([v]), lim_neighbors),
+                        combinations(set(graph.neighbors(v)) - set([u]), lim_neighbors),
                     ):
                         # If a conditioning set exists remove the edge, store the
                         # separating set and move on to finding conditioning set for next edge.
@@ -332,8 +334,9 @@ class PC(StructureEstimator):
                 neighbors = {node: set(graph[node]) for node in graph.nodes()}
 
                 def _parallel_fun(u, v):
-                    for separating_set in combinations(
-                        neighbors[u] - set([v]), lim_neighbors
+                    for separating_set in chain(
+                        combinations(set(graph.neighbors(u)) - set([v]), lim_neighbors),
+                        combinations(set(graph.neighbors(v)) - set([u]), lim_neighbors),
                     ):
                         if ci_test(
                             u,
@@ -411,22 +414,23 @@ class PC(StructureEstimator):
         --------
         >>> import pandas as pd
         >>> import numpy as np
-        >>> from pgmpy.estimators import ConstraintBasedEstimator
+        >>> from pgmpy.estimators import PC
         >>> data = pd.DataFrame(np.random.randint(0, 4, size=(5000, 3)), columns=list('ABD'))
         >>> data['C'] = data['A'] - data['B']
         >>> data['D'] += data['A']
-        >>> c = ConstraintBasedEstimator(data)
-        >>> pdag = c.skeleton_to_pdag(*c.estimate_skeleton())
+        >>> c = PC(data)
+        >>> pdag = c.skeleton_to_pdag(*c.build_skeleton())
         >>> pdag.edges() # edges: A->C, B->C, A--D (not directed)
         [('B', 'C'), ('A', 'C'), ('A', 'D'), ('D', 'A')]
         """
 
         pdag = skeleton.to_directed()
-        node_pairs = combinations(pdag.nodes(), 2)
+        node_pairs = list(permutations(pdag.nodes(), 2))
 
         # 1) for each X-Z-Y, if Z not in the separating set of X,Y, then orient edges as X->Z<-Y
         # (Algorithm 3.4 in Koller & Friedman PGM, page 86)
-        for X, Y in node_pairs:
+        for pair in node_pairs:
+            X, Y = pair
             if not skeleton.has_edge(X, Y):
                 for Z in set(skeleton.neighbors(X)) & set(skeleton.neighbors(Y)):
                     if Z not in separating_sets[frozenset((X, Y))]:
@@ -437,25 +441,31 @@ class PC(StructureEstimator):
             num_edges = pdag.number_of_edges()
 
             # 2) for each X->Z-Y, orient edges to Z->Y
-            for X, Y in node_pairs:
-                for Z in (set(pdag.successors(X)) - set(pdag.predecessors(X))) & (
-                    set(pdag.successors(Y)) & set(pdag.predecessors(Y))
-                ):
-                    pdag.remove(Y, Z)
+            # (Explanation in Koller & Friedman PGM, page 88)
+            for pair in node_pairs:
+                X, Y = pair
+                if not pdag.has_edge(X, Y):
+                    for Z in (set(pdag.successors(X)) - set(pdag.predecessors(X))) & (
+                        set(pdag.successors(Y)) & set(pdag.predecessors(Y))
+                    ):
+                        pdag.remove_edge(Y, Z)
 
             # 3) for each X-Y with a directed path from X to Y, orient edges to X->Y
-            for X, Y in node_pairs:
-                for path in nx.all_simple_paths(pdag, X, Y):
-                    is_directed = True
-                    for src, dst in path:
-                        if pdag.has_edge(dst, src):
-                            is_directed = False
-                    if is_directed:
-                        pdag.remove(Y, X)
-                        break
+            for pair in node_pairs:
+                X, Y = pair
+                if pdag.has_edge(Y, X) and pdag.has_edge(X, Y):
+                    for path in nx.all_simple_paths(pdag, X, Y):
+                        is_directed = True
+                        for src, dst in list(zip(path, path[1:])):
+                            if pdag.has_edge(dst, src):
+                                is_directed = False
+                        if is_directed:
+                            pdag.remove_edge(Y, X)
+                            break
 
             # 4) for each X-Z-Y with X->W, Y->W, and Z-W, orient edges to Z->W
-            for X, Y in node_pairs:
+            for pair in node_pairs:
+                X, Y = pair
                 for Z in (
                     set(pdag.successors(X))
                     & set(pdag.predecessors(X))
@@ -467,7 +477,7 @@ class PC(StructureEstimator):
                         & (set(pdag.successors(Y)) - set(pdag.predecessors(Y)))
                         & (set(pdag.successors(Z)) & set(pdag.predecessors(Z)))
                     ):
-                        pdag.remove(W, Z)
+                        pdag.remove_edge(W, Z)
 
             progress = num_edges > pdag.number_of_edges()
 
