@@ -4,10 +4,11 @@ from pgmpy.estimators.BayesianEstimator import BayesianEstimator
 from pgmpy.estimators.StructureScore import StructureScore, K2Score, BDeuScore, BicScore
 from pgmpy.estimators.ExhaustiveSearch import ExhaustiveSearch
 from pgmpy.estimators.HillClimbSearch import HillClimbSearch
-from pgmpy.estimators.ConstraintBasedEstimator import ConstraintBasedEstimator
+from pgmpy.estimators.TreeSearch import TreeSearch
 from pgmpy.estimators.SEMEstimator import SEMEstimator, IVEstimator
 from pgmpy.estimators.ScoreCache import ScoreCache
 from pgmpy.estimators.MmhcEstimator import MmhcEstimator
+from pgmpy.estimators.PC import PC
 
 __all__ = [
     "BaseEstimator",
@@ -17,7 +18,7 @@ __all__ = [
     "StructureEstimator",
     "ExhaustiveSearch",
     "HillClimbSearch",
-    "ConstraintBasedEstimator",
+    "TreeSearch",
     "StructureScore",
     "K2Score",
     "BDeuScore",
@@ -26,4 +27,5 @@ __all__ = [
     "SEMEstimator",
     "IVEstimator",
     "MmhcEstimator",
+    "PC",
 ]
