@@ -163,23 +163,23 @@ class Independencies(object):
         >>> from pgmpy.independencies import Independencies
         >>> ind1 = Independencies(('A', ['B', 'C'], 'D'))
         >>> ind1.closure()
-        (A _|_ B | D, C)
-        (A _|_ B, C | D)
-        (A _|_ B | D)
-        (A _|_ C | D, B)
-        (A _|_ C | D)
+        (A \u27C2 B | D, C)
+        (A \u27C2 B, C | D)
+        (A \u27C2 B | D)
+        (A \u27C2 C | D, B)
+        (A \u27C2 C | D)
 
         >>> ind2 = Independencies(('W', ['X', 'Y', 'Z']))
         >>> ind2.closure()
-        (W _|_ Y)
-        (W _|_ Y | X)
-        (W _|_ Z | Y)
-        (W _|_ Z, X, Y)
-        (W _|_ Z)
-        (W _|_ Z, X)
-        (W _|_ X, Y)
-        (W _|_ Z | X)
-        (W _|_ Z, Y | X)
+        (W \u27C2 Y)
+        (W \u27C2 Y | X)
+        (W \u27C2 Z | Y)
+        (W \u27C2 Z, X, Y)
+        (W \u27C2 Z)
+        (W \u27C2 Z, X)
+        (W \u27C2 X, Y)
+        (W \u27C2 Z | X)
+        (W \u27C2 Z, Y | X)
         [..]
         """
 
@@ -423,13 +423,13 @@ class IndependenceAssertion(object):
 
     def __str__(self):
         if self.event3:
-            return "({event1} _|_ {event2} | {event3})".format(
+            return "({event1} \u27C2 {event2} | {event3})".format(
                 event1=", ".join(self.event1),
                 event2=", ".join(self.event2),
                 event3=", ".join(self.event3),
             )
         else:
-            return "({event1} _|_ {event2})".format(
+            return "({event1} \u27C2 {event2})".format(
                 event1=", ".join(self.event1), event2=", ".join(self.event2)
             )
 
@@ -474,8 +474,13 @@ class IndependenceAssertion(object):
         return self.event1, self.event2, self.event3
 
     def latex_string(self):
-        return r"%s \perp %s \mid %s" % (
-            ", ".join(self.event1),
-            ", ".join(self.event2),
-            ", ".join(self.event3),
-        )
+        if len(self.event3) == 0:
+            return r"{event1} \perp {event2}".format(
+                event1=", ".join(self.event1), event2=", ".join(self.event2)
+            )
+        else:
+            return r"{event1} \perp {event2} \mid {event3}".format(
+                event1=", ".join(self.event1),
+                event2=", ".join(self.event2),
+                event3=", ".join(self.event3),
+            )
