@@ -2,12 +2,15 @@ from .base import Inference
 from .ExactInference import BeliefPropagation
 from .ExactInference import VariableElimination
 from .dbn_inference import DBNInference
+from .bn_inference import BayesianModelInference, BayesianModelProbability
 from .mplp import Mplp
 
 __all__ = [
     "Inference",
     "VariableElimination",
     "DBNInference",
+    "BayesianModelInference",
+    "BayesianModelProbability",
     "BeliefPropagation",
     "BayesianModelSampling",
     "GibbsSampling",
