@@ -1,12 +1,11 @@
 from collections import namedtuple
 import itertools
 
-import networkx as nx
 import numpy as np
 from tqdm import tqdm
 
 from pgmpy.factors import factor_product
-from pgmpy.inference import Inference
+from pgmpy.inference import BayesianModelInference
 from pgmpy.models import BayesianModel, MarkovChain, MarkovModel
 from pgmpy.utils.mathext import sample_discrete
 from pgmpy.sampling import _return_samples
@@ -16,7 +15,7 @@ from pgmpy.global_vars import SHOW_PROGRESS
 State = namedtuple("State", ["var", "state"])
 
 
-class BayesianModelSampling(Inference):
+class BayesianModelSampling(BayesianModelInference):
     """
     Class for sampling methods specific to Bayesian Models
 
@@ -27,12 +26,6 @@ class BayesianModelSampling(Inference):
     """
 
     def __init__(self, model):
-        if not isinstance(model, BayesianModel):
-            raise TypeError(
-                "Model expected type: BayesianModel, got type: ", type(model)
-            )
-
-        self.topological_order = list(nx.topological_sort(model))
         super(BayesianModelSampling, self).__init__(model)
 
     def forward_sample(
@@ -81,6 +74,9 @@ class BayesianModelSampling(Inference):
         else:
             pbar = self.topological_order
 
+        if seed is not None:
+            np.random.seed(seed)
+
         for node in pbar:
             if show_progress and SHOW_PROGRESS:
                 pbar.set_description(f"Generating for node: {node}")
@@ -94,25 +90,10 @@ class BayesianModelSampling(Inference):
                 weights = list(map(lambda t: cached_values[tuple(t)], evidence.T))
             else:
                 weights = cpd.values
-            sampled[node] = sample_discrete(states, weights, size, seed=seed)
+            sampled[node] = sample_discrete(states, weights, size)
 
         return _return_samples(return_type, sampled, self.state_names_map)
 
-    def pre_compute_reduce(self, variable):
-        variable_cpd = self.model.get_cpds(variable)
-        variable_evid = variable_cpd.variables[:0:-1]
-        cached_values = {}
-
-        for state_combination in itertools.product(
-            *[range(self.cardinality[var]) for var in variable_evid]
-        ):
-            states = list(zip(variable_evid, state_combination))
-            cached_values[state_combination] = variable_cpd.reduce(
-                states, inplace=False
-            ).values
-
-        return cached_values
-
     def rejection_sample(
         self,
         evidence=[],
@@ -166,9 +147,12 @@ class BayesianModelSampling(Inference):
             for var, state in evidence
         ]
 
+        if seed is not None:
+            np.random.seed(seed)
+
         # If no evidence is given, it is equivalent to forward sampling.
         if len(evidence) == 0:
-            return self.forward_sample(size, seed=seed)
+            return self.forward_sample(size)
 
         # Setup array to be returned
         types = [(var_name, "int") for var_name in self.topological_order]
@@ -184,7 +168,7 @@ class BayesianModelSampling(Inference):
 
         while i < size:
             _size = int(((size - i) / prob) * 1.5)
-            _sampled = self.forward_sample(_size, "recarray", seed=seed)
+            _sampled = self.forward_sample(_size, "recarray")
 
             for evid in evidence:
                 _sampled = _sampled[_sampled[evid[0]] == evid[1]]
@@ -248,7 +232,10 @@ class BayesianModelSampling(Inference):
         rec.array([(0, 0, 1, 0.6), (0, 0, 2, 0.6)], dtype=
                   [('diff', '<i8'), ('intel', '<i8'), ('grade', '<i8'), ('_weight', '<f8')])
         """
-        # Covert evidence state names to number
+        if seed is not None:
+            np.random.seed(seed)
+
+        # Convert evidence state names to number
         evidence = [
             (var, self.model.get_cpds(var).get_state_no(var, state))
             for var, state in evidence
@@ -278,14 +265,14 @@ class BayesianModelSampling(Inference):
                     for i in range(size):
                         sampled["_weight"][i] *= weights[i][evidence_dict[node]]
                 else:
-                    sampled[node] = sample_discrete(states, weights, size, seed=seed)
+                    sampled[node] = sample_discrete(states, weights, size)
             else:
                 if node in evidence_dict:
                     sampled[node] = evidence_dict[node]
                     for i in range(size):
                         sampled["_weight"][i] *= cpd.values[evidence_dict[node]]
                 else:
-                    sampled[node] = sample_discrete(states, cpd.values, size, seed=seed)
+                    sampled[node] = sample_discrete(states, cpd.values, size)
 
         # Postprocess the samples: Correct return type and change state numbers to names
         return _return_samples(return_type, sampled, self.state_names_map)
@@ -420,7 +407,7 @@ class GibbsSampling(MarkovChain):
 
         Examples
         --------
-        >>> from pgmpy.factors import DiscreteFactor
+        >>> from pgmpy.factors.discrete import DiscreteFactor
         >>> from pgmpy.sampling import GibbsSampling
         >>> from pgmpy.models import MarkovModel
         >>> model = MarkovModel([('A', 'B'), ('C', 'B')])
@@ -440,6 +427,9 @@ class GibbsSampling(MarkovChain):
         elif start_state is not None:
             self.set_start_state(start_state)
 
+        if seed is not None:
+            np.random.seed(seed)
+
         types = [(var_name, "int") for var_name in self.variables]
         sampled = np.zeros(size, dtype=types).view(np.recarray)
         sampled[0] = tuple(st for var, st in self.state)
@@ -449,7 +439,6 @@ class GibbsSampling(MarkovChain):
                 next_st = sample_discrete(
                     list(range(self.cardinalities[var])),
                     self.transition_models[var][other_st],
-                    seed=seed,
                 )[0]
                 self.state[j] = State(var, next_st)
             sampled[i + 1] = tuple(st for var, st in self.state)
@@ -479,6 +468,8 @@ class GibbsSampling(MarkovChain):
         [[State(var='C', state=1), State(var='B', state=1), State(var='A', state=0)],
          [State(var='C', state=0), State(var='B', state=1), State(var='A', state=1)]]
         """
+        if seed is not None:
+            np.random.seed(seed)
 
         if start_state is None and self.state is None:
             self.state = self.random_state()
@@ -491,7 +482,6 @@ class GibbsSampling(MarkovChain):
                 next_st = sample_discrete(
                     list(range(self.cardinalities[var])),
                     self.transition_models[var][other_st],
-                    seed=seed,
                 )[0]
                 self.state[j] = State(var, next_st)
             yield self.state[:]
